@@ -10,8 +10,7 @@ class HTTPBasicPriorAuthHandler(HTTPBasicAuthHandler):
 
     def http_request(self, req):
         if not req.has_header('Authorization'):
-            user, passwd = self.passwd.find_user_password(None,
-                                                          req.get_host())
+            user, passwd = self.passwd.find_user_password(None, req.host)
             credentials = '{0}:{1}'.format(user, passwd).encode()
             auth_str = standard_b64encode(credentials).decode()
             req.add_unredirected_header('Authorization',
